@@ -14,8 +14,8 @@ my $wait_time =1;
 my $suffixe =strftime "%Y%m%d%H%M%S", localtime;
 $wait_time ||=500*$cfg->{'EDTK_WAITRUN'};
 
-warn "WARN : ".$cfg->{'EDTK_DBI_OUTMNGR'}." and ".$cfg->{'EDTK_DBI_TRACKING'}." table should not be in use\n";
-warn "WARN : wait or press a key\n";
+warn "INFO : ".$cfg->{'EDTK_DBI_OUTMNGR'}." and ".$cfg->{'EDTK_DBI_TRACKING'}." table should not be in use\n";
+warn "INFO : wait or press a key\n";
 
 ReadMode('raw');
 my $key = ReadKey($wait_time);
@@ -24,4 +24,4 @@ ReadMode ('restore');
 historicize_table($dbh, $cfg->{'EDTK_DBI_OUTMNGR'}, $suffixe);
 historicize_table($dbh, $cfg->{'EDTK_DBI_TRACKING'}, $suffixe);
 
-warn "WARN : backup done for ".$cfg->{'EDTK_DBI_OUTMNGR'}." and ".$cfg->{'EDTK_DBI_TRACKING'}."\n";
+warn "INFO : backup done for ".$cfg->{'EDTK_DBI_OUTMNGR'}." and ".$cfg->{'EDTK_DBI_TRACKING'}."\n";
